@@ -47,7 +47,7 @@ ___BEGIN_DECLS
 extern char * xstrdup (const char *s);
 extern int display_fonts (const char *output_format, const char *progname);
 extern int list_fonts (const char *output_format, const char *progname);
-extern void display_usage (const char *progname, const int *omit_vals, const char *appendage, bool fonts);
+extern void display_usage (const char *progname, const int *omit_vals, const char *appendage, int info);
 extern void display_version (const char *progname, const char *written, const char *copyright);
 extern void * xmalloc (size_t length);
 extern void * xrealloc (void *p, size_t length);
