@@ -5,17 +5,8 @@
 #include "getopt.h"
 
 int
-#ifdef _HAVE_PROTOS
 getopt_long (int argc, char *const *argv, const char *options, 
 	     const struct option *long_options, int *opt_index)
-#else
-getopt_long (argc, argv, options, long_options, opt_index)
-     int argc;
-     char *const *argv;
-     const char *options;
-     const struct option *long_options;
-     int *opt_index;
-#endif
 {
   return _getopt_internal (argc, argv, options, long_options, opt_index, 0);
 }
@@ -26,17 +17,8 @@ getopt_long (argc, argv, options, long_options, opt_index)
    instead.  */
 
 int
-#ifdef _HAVE_PROTOS
 getopt_long_only (int argc, char *const *argv, const char *options,
 		  const struct option *long_options, int *opt_index)
-#else
-getopt_long_only (argc, argv, options, long_options, opt_index)
-     int argc;
-     char *const *argv;
-     const char *options;
-     const struct option *long_options;
-     int *opt_index;
-#endif
 {
   return _getopt_internal (argc, argv, options, long_options, opt_index, 1);
 }
