@@ -1,5 +1,5 @@
 /* This file is part of the GNU plotutils package.  Copyright (C) 1995,
-   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+   1996, 1997, 1998, 1999, 2000, 2005, 2008, Free Software Foundation, Inc.
 
    The GNU plotutils package is free software.  You may redistribute it
    and/or modify it under the terms of the GNU General Public License as
@@ -100,8 +100,7 @@ _API_flushpl (S___(Plotter *_plotter))
     }
 
   if (retval < 0)
-    _plotter->error (R___(_plotter) 
-		     "output stream jammed");
+    _plotter->error (R___(_plotter) "the output stream is jammed");
   return retval;
 }
 
