@@ -1,5 +1,5 @@
 /* This file is part of the GNU plotutils package.  Copyright (C) 1995,
-   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+   1996, 1997, 1998, 1999, 2000, 2005, 2008, Free Software Foundation, Inc.
 
    The GNU plotutils package is free software.  You may redistribute it
    and/or modify it under the terms of the GNU General Public License as
@@ -240,7 +240,7 @@ _pl_y_end_page (S___(Plotter *_plotter))
       bool retval = true;
 
       if ((int)forkval < 0)
-	_plotter->error (R___(_plotter) "couldn't fork process");	
+	_plotter->error (R___(_plotter) "the process could not be forked");
 
       /* Close connection to X display associated with window that the
 	 child process should manage, i.e. with the last openpl() invoked
@@ -249,7 +249,7 @@ _pl_y_end_page (S___(Plotter *_plotter))
 	  && errno != EINTR)
 	/* emphatically shouldn't happen */
 	{
-	  _plotter->error (R___(_plotter) "couldn't close connection to X display");
+	  _plotter->error (R___(_plotter) "the connection to the X display could not be closed");
 	  retval = false;
 	}
 
@@ -305,7 +305,7 @@ _pl_y_end_page (S___(Plotter *_plotter))
 	    && errno != EINTR)
 	  /* shouldn't happen */
 	  _plotter->error (R___(_plotter)
-			   "couldn't close connection to X display");
+			   "the connection to the X display could not be closed");
 
       /* Repaint by sending an expose event to ourselves, copying the Label
 	 widget's background pixmap into its window.  This is a good idea
